sdfjklsdfsjldkflkjsf, sdfjsdfjlksdljkfsdlkf, sdfsdjfklsdfjlksdljkf, sdsfsdfjskdflsfsdf = 1, 2, 3


# output
(
    sdfjklsdfsjldkflkjsf,
    sdfjsdfjlksdljkfsdlkf,
    sdfsdjfklsdfjlksdljkf,
    sdsfsdfjskdflsfsdf,
) = (1, 2, 3)
